<?php

namespace Drupal\important_information\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;


/**
 * Configure important_information content.
 */
class ImportantInformationSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'important_information_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'important_information.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $settings = $this->config('important_information.settings');
/*
    // Sidebar
    $sidebar_parent = $settings->get('sidebar_parent');
    $sidebar_container = $settings->get('sidebar_container');
    $form['sidebar'] = array(
      '#type' => 'details',
      '#title' => $this->t('Sticky Sidebar Settings'),
      '#collapsible' => TRUE,
    );
    $form['sidebar']['sidebar_parent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Parent'),
      '#default_value' => isset($sidebar_parent) ? $sidebar_parent: '',
      '#description' => $this->t('See https://abouolia.github.io/sticky-sidebar/#usage for more information.'),
    ];
    $form['sidebar']['sidebar_container'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Container'),
      '#default_value' => isset($sidebar_container) ? $sidebar_container: '',
      '#description' => $this->t('See https://abouolia.github.io/sticky-sidebar/#usage for more information.'),
    ];
*/
    // Floating Container
    $collapsed_percent = $settings->get('collapsed_percent');
    $expanded_percent = $settings->get('expanded_percent');
    $container_hide = $settings->get('container_hide');
    $full_size = $settings->get('full_size');
    $modal_width = $settings->get('modal_width');
    $container_height = $settings->get('container_height');
    $exit_modal_width = $settings->get('exit_modal_width');

    // Floating Container Sidebar
    $container_sidebar_behavior = $settings->get('container_sidebar_behavior');
    $container_sidebar_y_offset = $settings->get('container_sidebar_y_offset');
    $form['container_sidebar'] = array(
      '#type' => 'details',
      '#title' => $this->t('Floating Container Sidebar Settings'),
      '#collapsible' => TRUE,
    );
    $options = [
      'absolute' => $this->t('Sidebar is stuck in the same position, absolutely positioned'),
      'fixed' => $this->t('Sidebar is stuck in the same position, ensuring that it is always in the same place relative to the viewport (i.e. floating in place), fixed position'),
      'absolute_fixed' => $this->t('Sidebar starts absolutely positioned, but switches to fixed at a certain distance while the user scrolls down the page.'),
    ];
    $form['container_sidebar']['container_sidebar_behavior'] = [
      '#type' => 'radios',
      '#title' => $this->t('Behavior'),
      '#options' => $options,
      '#default_value' => isset($container_sidebar_behavior) ? $container_sidebar_behavior : 'absolute',
      '#description' => $this->t('Choose the behavior the Floating Container Sidebar should have.'),
      '#multiple' => FALSE,
    ];
    $form['container_sidebar']['container_sidebar_y_offset'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Vertical Offset'),
      '#default_value' => isset($container_sidebar_y_offset) ? $container_sidebar_y_offset : '0',
      '#description' => $this->t('Set the placement of the Floating Container Sidebar, in pixels (numbers only). Also serves as the Y position at which absolute switches to fixed if that is the behavior option set.'),
    ];

    // Acknowledge Container
    $ack_modal_width = $settings->get('ack_modal_width');

    $form['floating_container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Floating Container Settings'),
      '#collapsible' => TRUE,
    );
    $form['floating_container']['container_hide'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide Floating Container'),
      '#default_value' => isset($container_hide) ? $container_hide: FALSE,
      '#description' => $this->t('When Embedded Bottom is in the viewport, Floating Container will be hidden.'),
    ];
    $form['floating_container']['offset'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Hide/show Offset'),
      '#default_value' => isset($offset) ? $offset: 0,
      '#description' => $this->t('Adjust the calibration of the Embedded Bottom detection; lower than zero makes it happen faster.'),
    ];
    $form['floating_container']['full_size'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Full-size Modal'),
      '#default_value' => isset($full_size) ? $full_size: FALSE,
      '#description' => $this->t('Provides a button to present the Important Information in a full screen modal.'),
    ];
    $form['floating_container']['modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Modal Width'),
      '#default_value' => isset($modal_width) ? $modal_width: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen modal will cover.'),
    ];
    $form['floating_container']['container_height'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Container Height'),
      '#default_value' => isset($container_height) ? $container_height: IMPORTANT_INFORMATION_CONTAINER_HEIGHT_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen container will initial cover vertically.'),
    ];
    $form['floating_container']['collapsed_percent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Percentage of viewport the collapsed Floating Container occupies'),
      '#default_value' => isset($collapsed_percent) ? $collapsed_percent: IMPORTANT_INFORMATION_FOOTER_COLLAPSED_PERCENT_DEFAULT,
      '#description' => $this->t('Numbers only, do not add the %.'),
    ];
    $form['floating_container']['expanded_percent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Percentage of viewport the expanded Floating Container occupies'),
      '#default_value' => isset($expanded_percent) ? $expanded_percent: IMPORTANT_INFORMATION_FOOTER_EXPANDED_PERCENT_DEFAULT,
      '#description' => $this->t('Numbers only, do not add the %.'),
    ];
    $form['exit_container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Exit Container Settings'),
      '#collapsible' => TRUE,
    );
    $form['exit_container']['exit_modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Exit Modal Width'),
      '#default_value' => isset($exit_modal_width) ? $exit_modal_width: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen modal will cover.'),
    ];

    $form['acknowledge_container'] = array(
      '#type' => 'details',
      '#title' => $this->t('Acknowledge Container Settings'),
      '#collapsible' => TRUE,
    );
    $form['acknowledge_container']['ack_modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('% of Modal Width'),
      '#default_value' => isset($ack_modal_width) ? $ack_modal_width: IMPORTANT_INFORMATION_MODAL_WIDTH_PERCENT_DEFAULT,
      '#description' => $this->t('Percent of the screen modal will cover.'),
    ];

/*
    $force_intro = $settings->get('force_intro');
    $append_bottom = $settings->get('append_bottom');
    $append_bottom_hide_sidebar = $settings->get('append_bottom_hide_sidebar');
    $append_bottom_hide_footer = $settings->get('append_bottom_hide_footer');
    $vertical_offset = $settings->get('vertical_offset');
    $attach_to = $settings->get('attach_to');

    $form['intro'] = array(
      '#type' => 'details',
      '#title' => $this->t('Important Information intro details'),
      '#collapsible' => TRUE,
    );
    // TODO: make cookie duration configurable
    $form['intro']['force_intro'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Intro Modal'),
      '#default_value' => isset($force_intro) ? $force_intro : FALSE,
      '#description' => $this->t('Presents first-time visits to site the Important Information intro in a modal. Acknowledging the modal  will  set a cookie to remember  the user  for 7  days.'),
    );
    $form['leave_site'] = array(
      '#type' => 'details',
      '#title' => $this->t('Important Information exit details'),
      '#collapsible' => TRUE,
    );
    $form['leave_site']['interstitial'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Exit Modal'),
      '#default_value' => isset($force_intro) ? $force_intro : FALSE,
      '#description' => $this->t('Users leaving  the site via in-site navigation will be  presented the Important Information interstitial in a modal.'),
    );

*/
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('important_information.settings')
      // Set the submitted configuration setting
      //->set('sidebar_parent', $form_state->getValue('sidebar_parent'))
      //->set('sidebar_container', $form_state->getValue('sidebar_container'))
      ->set('container_hide', $form_state->getValue('container_hide'))
      ->set('full_size', $form_state->getValue('full_size'))
      ->set('modal_width', $form_state->getValue('modal_width'))
      ->set('container_height', $form_state->getValue('container_height'))
      ->set('ack_modal_width', $form_state->getValue('ack_modal_width'))
      ->set('exit_modal_width', $form_state->getValue('exit_modal_width'))
      ->set('container_sidebar_behavior', $form_state->getValue('container_sidebar_behavior'))
      ->set('container_sidebar_y_offset', $form_state->getValue('container_sidebar_y_offset'))
      ->save();

    parent::submitForm($form, $form_state);

  }
}